@@ -151,7 +151,7 @@ mod supported {
             .to_str()
             .expect("path to be converted to str");
 
-        ctx.sql(&format!("CREATE EXTERNAL TABLE written_table (id INTEGER, string_col STRING, timestamp_col BIGINT) STORED AS PARQUET LOCATION '{}'" , write_dir_path)).await.unwrap().show().await.unwrap();
+        ctx.sql(&format!("CREATE EXTERNAL TABLE written_table (id INTEGER, string_col STRING, timestamp_col BIGINT) STORED AS PARQUET LOCATION '{write_dir_path}'")).await.unwrap().show().await.unwrap();
 
         let plan = ctx
             .sql("INSERT INTO written_table select  id, string_col, timestamp_col from test")
@@ -337,7 +337,7 @@ mod supported {
         ctx: SessionContext,
         test_data: String,
     ) -> datafusion::error::Result<()> {
-        ctx.sql(&format!("CREATE EXTERNAL TABLE tbl_test STORED AS PARQUET LOCATION '{}/alltypes_plain.parquet'", test_data, )).await?.show().await?;
+        ctx.sql(&format!("CREATE EXTERNAL TABLE tbl_test STORED AS PARQUET LOCATION '{test_data}/alltypes_plain.parquet'", )).await?.show().await?;
 
         let result = ctx
             .sql("select id, string_col, timestamp_col from tbl_test where id > 4")
@@ -498,16 +498,17 @@ mod supported {
         ctx: SessionContext,
     ) -> datafusion::error::Result<()> {
         let result = ctx
-            .sql("select name, value from information_schema.df_settings where name like 'datafusion.execution.parquet.schema_force_view_types' order by name limit 1")
+            .sql("select name, value from information_schema.df_settings where name like 'datafusion.execution.parquet.schema_force_view_types' or name like 'datafusion.sql_parser.map_varchar_to_utf8view' order by name limit 2")
             .await?
             .collect()
             .await?;
-        //
+
         let expected = [
             "+------------------------------------------------------+-------+",
             "| name                                                 | value |",
             "+------------------------------------------------------+-------+",
             "| datafusion.execution.parquet.schema_force_view_types | false |",
+            "| datafusion.sql_parser.map_varchar_to_utf8view        | false |",
             "+------------------------------------------------------+-------+",
         ];
 
@@ -574,7 +575,7 @@ mod supported {
             .to_str()
             .expect("path to be converted to str");
 
-        ctx.sql(&format!("CREATE EXTERNAL TABLE written_table (id INTEGER, string_col STRING, timestamp_col BIGINT) STORED AS PARQUET LOCATION '{}'" , write_dir_path)).await.unwrap().show().await.unwrap();
+        ctx.sql(&format!("CREATE EXTERNAL TABLE written_table (id INTEGER, string_col STRING, timestamp_col BIGINT) STORED AS PARQUET LOCATION '{write_dir_path}'")).await.unwrap().show().await.unwrap();
 
         let _ = ctx
             .sql("INSERT INTO written_table select  id, string_col, timestamp_col from test")
