@@ -18,8 +18,8 @@
 
 //! Ballista configuration
 
-use std::collections::HashMap;
 use std::result;
+use std::{collections::HashMap, fmt::Display};
 
 use crate::error::{BallistaError, Result};
 
@@ -259,7 +259,6 @@ impl datafusion::config::ConfigExtension for BallistaConfig {
 }
 
 // an enum used to configure the scheduler policy
-// needs to be visible to code generated by configure_me
 
 /// Ballista supports both push-based and pull-based task scheduling.
 /// It is recommended that you try both to determine which is the best for your use case.
@@ -272,6 +271,14 @@ pub enum TaskSchedulingPolicy {
     /// push-based scheduling can result in lower latency.
     PushStaged,
 }
+impl Display for TaskSchedulingPolicy {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            TaskSchedulingPolicy::PullStaged => f.write_str("pull-staged"),
+            TaskSchedulingPolicy::PushStaged => f.write_str("push-staged"),
+        }
+    }
+}
 
 #[cfg(feature = "build-binary")]
 impl std::str::FromStr for TaskSchedulingPolicy {
@@ -281,15 +288,8 @@ impl std::str::FromStr for TaskSchedulingPolicy {
         clap::ValueEnum::from_str(s, true)
     }
 }
-#[cfg(feature = "build-binary")]
-impl configure_me::parse_arg::ParseArgFromStr for TaskSchedulingPolicy {
-    fn describe_type<W: core::fmt::Write>(mut writer: W) -> core::fmt::Result {
-        write!(writer, "The scheduler policy for the scheduler")
-    }
-}
 
 // an enum used to configure the log rolling policy
-// needs to be visible to code generated by configure_me
 #[derive(Clone, Copy, Debug, serde::Deserialize, Default)]
 #[cfg_attr(feature = "build-binary", derive(clap::ValueEnum))]
 pub enum LogRotationPolicy {
@@ -300,6 +300,17 @@ pub enum LogRotationPolicy {
     Never,
 }
 
+impl Display for LogRotationPolicy {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        match self {
+            LogRotationPolicy::Minutely => f.write_str("minutely"),
+            LogRotationPolicy::Hourly => f.write_str("hourly"),
+            LogRotationPolicy::Daily => f.write_str("daily"),
+            LogRotationPolicy::Never => f.write_str("never"),
+        }
+    }
+}
+
 #[cfg(feature = "build-binary")]
 impl std::str::FromStr for LogRotationPolicy {
     type Err = String;
@@ -309,13 +320,6 @@ impl std::str::FromStr for LogRotationPolicy {
     }
 }
 
-#[cfg(feature = "build-binary")]
-impl configure_me::parse_arg::ParseArgFromStr for LogRotationPolicy {
-    fn describe_type<W: core::fmt::Write>(mut writer: W) -> core::fmt::Result {
-        write!(writer, "The log rotation policy")
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
