@@ -93,7 +93,11 @@ impl std::fmt::Display for ShuffleWriterExec {
         write!(
             f,
             "ShuffleWriterExec: job={} stage={} work_dir={} partitioning={:?} plan: \n {}",
-            self.job_id, self.stage_id, self.work_dir, self.shuffle_output_partitioning, printable_plan
+            self.job_id,
+            self.stage_id,
+            self.work_dir,
+            self.shuffle_output_partitioning,
+            printable_plan
         )
     }
 }
@@ -188,7 +192,7 @@ impl ShuffleWriterExec {
     }
 
     pub fn execute_shuffle_write(
-        &self,
+        self,
         input_partition: usize,
         context: Arc<TaskContext>,
     ) -> impl Future<Output = Result<Vec<ShuffleWritePartition>>> {
@@ -211,7 +215,7 @@ impl ShuffleWriterExec {
                     std::fs::create_dir_all(&path)?;
                     path.push("data.arrow");
                     let path = path.to_str().unwrap();
-                    debug!("Writing results to {}", path);
+                    debug!("Writing results to {path}");
 
                     // stream results to disk
                     let stats = utils::write_stream_to_disk(
@@ -283,7 +287,7 @@ impl ShuffleWriterExec {
                                         path.push(format!(
                                             "data-{input_partition}.arrow"
                                         ));
-                                        debug!("Writing results to {:?}", path);
+                                        debug!("Writing results to {path:?}");
 
                                         let options = IpcWriteOptions::default()
                                             .try_with_compression(Some(
@@ -322,11 +326,7 @@ impl ShuffleWriterExec {
                             w.writer.finish()?;
                             debug!(
                                 "Finished writing shuffle partition {} at {:?}. Batches: {}. Rows: {}. Bytes: {}.",
-                                i,
-                                w.path,
-                                w.num_batches,
-                                w.num_rows,
-                                num_bytes
+                                i, w.path, w.num_batches, w.num_rows, num_bytes
                             );
 
                             part_locs.push(ShuffleWritePartition {
@@ -413,6 +413,7 @@ impl ExecutionPlan for ShuffleWriterExec {
 
         let schema_captured = schema.clone();
         let fut_stream = self
+            .clone()
             .execute_shuffle_write(partition, context)
             .and_then(|part_loc| async move {
                 // build metadata result batch
@@ -455,7 +456,7 @@ impl ExecutionPlan for ShuffleWriterExec {
                     vec![partition_num, path, stats],
                 )?;
 
-                debug!("RESULTS METADATA:\n{:?}", batch);
+                debug!("RESULTS METADATA:\n{batch:?}");
 
                 MemoryStream::try_new(vec![batch], schema_captured, None)
             })
@@ -471,8 +472,8 @@ impl ExecutionPlan for ShuffleWriterExec {
         Some(self.metrics.clone_inner())
     }
 
-    fn statistics(&self) -> Result<Statistics> {
-        self.plan.statistics()
+    fn partition_statistics(&self, partition: Option<usize>) -> Result<Statistics> {
+        self.plan.partition_statistics(partition)
     }
 }
 
@@ -509,7 +510,7 @@ mod tests {
             "jobOne".to_owned(),
             1,
             input_plan,
-            work_dir.into_path().to_str().unwrap().to_owned(),
+            work_dir.path().to_str().unwrap().to_owned(),
             Some(Partitioning::Hash(vec![Arc::new(Column::new("a", 0))], 2)),
         )?;
         let mut stream = query_stage.execute(0, task_ctx)?;
@@ -566,7 +567,7 @@ mod tests {
             "jobOne".to_owned(),
             1,
             input_plan,
-            work_dir.into_path().to_str().unwrap().to_owned(),
+            work_dir.path().to_str().unwrap().to_owned(),
             Some(Partitioning::Hash(vec![Arc::new(Column::new("a", 0))], 2)),
         )?;
         let mut stream = query_stage.execute(0, task_ctx)?;
